'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

exports['default'] = getDashBoardPath;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _nunjucks = require('nunjucks');

var _nunjucks2 = _interopRequireDefault(_nunjucks);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _context = require('./context');

var _context2 = _interopRequireDefault(_context);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var dashboardTemplate = _fs2['default'].readFileSync(_path2['default'].join(__dirname, '../../nunjucks/dashboard.nunjucks.js')).toString();

/**
 * 构建一个语法字符串
 * @param {*} namespace 
 * @param {*} dir 
 * 返回：
 *  "iam/功能组件名": ()=> import("组件路径")
 */
function getDashBoardComponents(namespace, dir) {
  return _glob2['default'].sync(_path2['default'].join(process.cwd(), dir)).map(function (f) {
    return '"' + namespace + '/' + _path2['default'].basename(f, _path2['default'].extname(f)) + '": () => import("' + f + '"),';
  });
}

/**
 * 构建一个组件引用对象字符串
 * @param {} dashboard 
 * 返回：
 *   JSON.stringify({
 *      "iam/功能组件名": ()=> import("组件路径"),
 *      "itsm/功能组件名": ()=> import("组件路径"),
 *      ...
 *   })
 */
function getDashBoards(dashboard) {
  var data = [];
  if (dashboard) {
    Object.keys(dashboard).forEach(function (key) {
      [].concat(dashboard[key]).forEach(function (dir) {
        data.push.apply(data, (0, _toConsumableArray3['default'])(getDashBoardComponents(key, dir)));
      });
    });
  }
  return '{\n' + data.join('\n') + '\n}';
}

/**
 * 功能：
 * 1.生成一个dashboard.[configEntryName].js文件
 * 2.返回该文件的文件路径
 * @param {}} configEntryName 配置的文件名
 * 返回：
 *   文件路径 ./tmp/dashboard.[configEntryName].js
 */
function getDashBoardPath(configEntryName) {
  var dashboard = _context2['default'].choerodonConfig.dashboard,
      tmpDirPath = _context2['default'].tmpDirPath;
  // 构建一个缓存文件路径 => 如：./tmp/dashboard.index.js

  var dashboardPath = _path2['default'].join(tmpDirPath, 'dashboard.' + configEntryName + '.js');
  _nunjucks2['default'].configure(dashboardPath, {
    autoescape: false
  });
  // 生成这个缓存文件 => 如：./tmp/dashboard.index.js
  _fs2['default'].writeFileSync(dashboardPath, _nunjucks2['default'].renderString(dashboardTemplate, {
    dashboard: getDashBoards(dashboard)
  }));
  return dashboardPath;
}