'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

exports['default'] = installSubmoduleDependencies;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _getPackagePath = require('./getPackagePath');

var _getPackagePath2 = _interopRequireDefault(_getPackagePath);

var _getPackageRoute = require('./getPackageRoute');

var _getPackageRoute2 = _interopRequireDefault(_getPackageRoute);

var _context = require('./context');

var _context2 = _interopRequireDefault(_context);

var _runCmd = require('./runCmd');

var _runCmd2 = _interopRequireDefault(_runCmd);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function install(done) {
  (0, _runCmd2['default'])(process.platform === 'win32' ? 'npm.cmd' : 'npm', ['i'], done);
}

/**
 * 功能：
 * 1.获取所有子模块的dependencies依赖项
 * 2.将所有子模块的入口文件，挂到webpack配置文件的routes属性上
 * 
 * 返回:
 * {
 *    ...所有子项目的denpendencies依赖项
 * }
 * @param {*} modules 
 * @param {*} dependencies 
 */
function getDependenciesByModules(modules, dependencies) {
  var choerodonConfig = _context2['default'].choerodonConfig;

  var deps = {};
  var routes = modules.reduce(function (obj, module) {
    // 子模块package.json内容
    var packageInfo = require((0, _getPackagePath2['default'])(module));
    // 将所有子模块的denpendencies挂到deps对象保存 => {...所有子模块package.json denpendencies的依赖包}
    (0, _extends3['default'])(deps, packageInfo[dependencies]);
    // 把子模块入口文件也挂到routes对象上 => {iam, itsm, report, im, robot, project}
    return (0, _extends3['default'])(obj, (0, _getPackageRoute2['default'])(packageInfo, module));
  }, {});

  // 将所有子模块的routes挂到weipack配置对象
  if (!choerodonConfig.routes) {
    choerodonConfig.routes = routes;
  }

  return deps;
}

function installSubmoduleDependencies(program, cb) {
  // 获取package.json的路径
  var mainPackagePath = (0, _getPackagePath2['default'])();
  // 读取package.json的内容
  var mainPackage = require(mainPackagePath);
  // 获取主项目+所有子项目的dependencies依赖包 => {...子项目依赖包，...主项目依赖包}
  mainPackage.dependencies = (0, _extends3['default'])(getDependenciesByModules(program.args, 'dependencies'), mainPackage.dependencies);
  // 获取主项目+所有子项目的peerDependencies依赖包 => {...子项目依赖包，...主项目依赖包}
  mainPackage.peerDependencies = (0, _extends3['default'])(getDependenciesByModules(program.args, 'peerDependencies'), mainPackage.peerDependencies);
  // 生成一个包含子项目依赖的package.json到根路径
  _fs2['default'].writeFileSync(mainPackagePath, JSON.stringify(mainPackage));
  // npm install 所有依赖包
  install(function () {
    return cb(mainPackage);
  });
}