'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports['default'] = getEnterPointsConfig;
/**
 * 功能：生产环境的环境变量配置
 * 定义环境变量的锚点值 KEY:VALUE(需要去具体的项目，也就是front parentStructure中定义替换命令语句）
 *
 * 如
 *    环境变量                    生产锚点值(需要替换成实际地址)
 *    CHAT_CUSTOMER_ONLINE: 'ENV_PROTOCOL://PRO_CHAT_CUSTOMER_ONLINE'
 *                                       |
 *                                      \|/
 *    替换后
 *    CHAT_CUSTOMER_ONLINE => https://csframe.dev.hand-ams.com
 *                                       |
 *                                      \|/
 *    则需要在yqcloud-front项目的parentStructure中定义
 *    find /usr/share/nginx/html -name '*.js' | xargs sed -i "s ENV_PROTOCOL $PRO_HTTP g"
 *    find /usr/share/nginx/html -name '*.js' | xargs sed -i "s PRO_CHAT_CUSTOMER_ONLINE $PRO_CHAT_CUSTOMER_ONLINE g"
 *
 *  以上步骤缺一不可！
 */
var enterPoints = {
  // http/https协议
  ENV_PROTOCOL: 'ENV_PROTOCOL',
  // 后端接口域名
  API_HOST: 'ENV_PROTOCOL://PRO_API_HOST',
  // 登录域名
  AUTH_HOST: 'ENV_PROTOCOL://PRO_API_HOST/oauth',
  // 服务门户域名
  SERVICE_PORTALS_HOST: 'ENV_PROTOCOL://SERVICE_PORTALS_HOST',
  // 报表socket域名
  WEBSOCKET_SERVER: 'PRO_WEBSOCKET_SERVER',
  // 知识协作socket域名
  WEBSOCKET_SERVER_KNOWLEDGE: 'WEBSOCKET_SERVER_KNOWLEDGE',
  // 知识空间域名
  KNOWLEDGE_SPACE_DOMAIN: 'ENV_PROTOCOL://KNOWLEDGE_SPACE_DOMAIN',
  // clientID
  CLIENT_ID: 'PRO_CLIENT_ID',
  // 标识是否是本地开发，线上无需配置
  LOCAL: 'PRO_LOCAL',
  // page content title我也不知道是什么鬼
  HEADER_TITLE_NAME: 'PRO_HEADER_TITLE_NAME',
  // cookie host 没有协议
  COOKIE_SERVER: 'PRO_COOKIE_SERVER',
  // 标识是否本地开发
  VERSION: 'localhost:version',
  // 网页标题设置
  TITLE_NAME: 'PRO_TITLE_NAME',
  // 图标服务器
  IMG_HOST: 'PRO_IMG_HOST',
  // 机器人域名
  CHAT_HOST: 'ENV_PROTOCOL://CHATBOT_HOST',
  // 脉信录音地址
  ENV_MAIXIN_RECORD: 'ENV_MAIXIN_RECORD',
  // 在线客服工作台地址
  WORK_STATION_HOST: 'ENV_PROTOCOL://WORK_STATION_HOST',
  // 在线客服机器人地址
  CHAT_CUSTOMER_ONLINE: 'ENV_PROTOCOL://PRO_CHAT_CUSTOMER_ONLINE',
  // http需要不提示的状态码
  CLOSE_ERROR_MESSAGE_CONFIG: 'CLOSE_ERROR_MESSAGE_CONFIG',
  // 上传组件检测是否分片上传
  ENV_UPLOAD_FRAG: 'ENV_UPLOAD_FRAG'
};

function getEnterPointsConfig() {
  return enterPoints;
}