'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

exports['default'] = updateWebpackConfig;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _extractTextWebpackPlugin = require('extract-text-webpack-plugin');

var _extractTextWebpackPlugin2 = _interopRequireDefault(_extractTextWebpackPlugin);

var _htmlWebpackPlugin = require('html-webpack-plugin');

var _htmlWebpackPlugin2 = _interopRequireDefault(_htmlWebpackPlugin);

var _context = require('../bin/common/context');

var _context2 = _interopRequireDefault(_context);

var _getStyleLoadersConfig = require('./getStyleLoadersConfig');

var _getStyleLoadersConfig2 = _interopRequireDefault(_getStyleLoadersConfig);

var _getEnterPointsConfig = require('./getEnterPointsConfig');

var _getEnterPointsConfig2 = _interopRequireDefault(_getEnterPointsConfig);

var _getWebpackCommonConfig = require('./getWebpackCommonConfig');

var _getWebpackCommonConfig2 = _interopRequireDefault(_getWebpackCommonConfig);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var choerodonLib = _path2['default'].join(__dirname, '..'); /**
                                                             * 组织webpack配置文件 webpackConfig: {}
                                                             * 1.组装入口配置
                                                             * 2.组装环境变量配置
                                                             * 3.组装输入配置
                                                             * 4.组装样式loader配置
                                                             */

function getFilePath(file) {
  var filePath = _path2['default'].join(process.cwd(), file);
  return _fs2['default'].existsSync(filePath) ? filePath : _path2['default'].join(__dirname, '..', file);
}

function updateWebpackConfig(mode, env) {
  var webpackConfig = (0, _getWebpackCommonConfig2['default'])(mode, env);
  var choerodonConfig = _context2['default'].choerodonConfig;
  var theme = choerodonConfig.theme,
      output = choerodonConfig.output,
      root = choerodonConfig.root,
      enterPoints = choerodonConfig.enterPoints,
      server = choerodonConfig.server,
      clientid = choerodonConfig.clientid,
      local = choerodonConfig.local,
      wsServerDownload = choerodonConfig.wsServerDownload,
      webSocketUrl = choerodonConfig.webSocketUrl,
      wsServerKnowledge = choerodonConfig.wsServerKnowledge,
      knowledgeSpaceDomain = choerodonConfig.knowledgeSpaceDomain,
      closeErrorMessageConfig = choerodonConfig.closeErrorMessageConfig,
      postcssConfig = choerodonConfig.postcssConfig,
      entryName = choerodonConfig.entryName,
      titlename = choerodonConfig.titlename,
      htmlTemplate = choerodonConfig.htmlTemplate,
      favicon = choerodonConfig.favicon,
      dashboard = choerodonConfig.dashboard,
      wsServer = choerodonConfig.wsServer,
      servicePortalsUrl = choerodonConfig.servicePortalsUrl,
      imgUrl = choerodonConfig.imgUrl,
      maixinRecord = choerodonConfig.maixinRecord,
      chatHost = choerodonConfig.chatHost,
      customerServiceUrl = choerodonConfig.customerServiceUrl,
      workStationHost = choerodonConfig.workStationHost,
      uploadFrag = choerodonConfig.uploadFrag;

  var styleLoadersConfig = (0, _getStyleLoadersConfig2['default'])(postcssConfig, {
    sourceMap: true,
    modifyVars: theme
  });

  var defaultEnterPoints = void 0;
  webpackConfig.entry = {};
  if (mode === 'start') {
    webpackConfig.output.publicPath = '/';
    webpackConfig.devtool = 'cheap-module-eval-source-map';
    webpackConfig.watch = true;
    // webpack样式loader配置
    styleLoadersConfig.forEach(function (config) {
      webpackConfig.module.rules.push({
        test: config.test,
        use: ['style-loader'].concat((0, _toConsumableArray3['default'])(config.use))
      });
    });
    /**
     * 配置环境变量本地值的读取
     * 格式 = 环境变量：对应代码中的变量
     * 如
     * CHAT_CUSTOMER_ONLINE:customerServiceUrl
     * CHAT_CUSTOMER_ONLINE => 环境变量名
     * customerServiceUrl   => 赋值配置文件getChoerodonConfig.js中本地代码变量customerServiceUrl的值过来，便于本地调试
     */
    defaultEnterPoints = {
      // 服务端接口域名
      API_HOST: server,
      // 登录域名
      AUTH_HOST: server + '/oauth',
      // clientId
      CLIENT_ID: clientid,
      // 是否本地开发
      LOCAL: local,
      // 没啥用
      VERSION: '本地',
      // 报表socket域名
      WEBSOCKET_SERVER: wsServer,
      // 知识库写作socket域名
      WEBSOCKET_SERVER_KNOWLEDGE: wsServerKnowledge,
      // 需要关闭的提示的http状态码
      CLOSE_ERROR_MESSAGE_CONFIG: closeErrorMessageConfig,
      // 静态图片服务器地址
      IMG_HOST: imgUrl,
      // 机器人域名 应该是开放大学那个
      CHAT_HOST: chatHost,
      // 在线客服机器人域名
      CHAT_CUSTOMER_ONLINE: customerServiceUrl,
      // 在线客服工作台域名
      WORK_STATION_HOST: workStationHost,
      // 脉信录音地址
      ENV_MAIXIN_RECORD: maixinRecord,
      // 知识空间域名
      KNOWLEDGE_SPACE_DOMAIN: knowledgeSpaceDomain,
      // 上传组件检测是否分片上传
      ENV_UPLOAD_FRAG: uploadFrag
    };
  } else if (mode === 'build') {
    webpackConfig.output.publicPath = root;
    webpackConfig.output.path = _path2['default'].join(process.cwd(), output);
    // 将样式loader配置注入到webpack配置文件 webpackConfig
    styleLoadersConfig.forEach(function (config) {
      webpackConfig.module.rules.push({
        test: config.test,
        use: _extractTextWebpackPlugin2['default'].extract({
          use: config.use
        })
      });
    });
    defaultEnterPoints = (0, _getEnterPointsConfig2['default'])();
  }
  /* eslint-enable no-param-reassign */
  // 将所有的环境变量声明都合并到一个对象 mergedEnterPoints
  var mergedEnterPoints = (0, _extends3['default'])({
    NODE_ENV: env,
    USE_DASHBOARD: !!dashboard
  }, defaultEnterPoints, enterPoints(mode, env));

  // 定义webpack环境变量
  var defines = Object.keys(mergedEnterPoints).reduce(function (obj, key) {
    obj['process.env.' + key] = JSON.stringify(process.env[key] || mergedEnterPoints[key]);
    return obj;
  }, {});

  // 用webpackConfig回调重新拿一遍config => customizedWebpackConfig 实际这一步啥也没干
  var customizedWebpackConfig = choerodonConfig.webpackConfig(webpackConfig, _webpack2['default']);

  // 因为入口配置是是动态生成的（子模块route生成的entry.index.js），所以要禁止用户自己定义一个webpack入口entry配置
  if (customizedWebpackConfig.entry[entryName]) {
    throw new Error('Should not set `webpackConfig.entry.' + entryName + '`!');
  }

  // 将动态生成的入口文件加到入口配置
  var entryPath = _path2['default'].join(choerodonLib, '..', 'tmp', 'entry.' + entryName + '.js');
  customizedWebpackConfig.entry[entryName] = entryPath;

  // 将自定义的webpack插件挂到webpack插件配置
  customizedWebpackConfig.plugins.push(new _webpack2['default'].DefinePlugin(defines), new _htmlWebpackPlugin2['default']({
    title: process.env.TITLE_NAME || titlename,
    template: getFilePath(htmlTemplate),
    inject: true,
    favicon: getFilePath(favicon),
    minify: {
      html5: true,
      collapseWhitespace: true,
      removeComments: true,
      removeTagWhitespace: true,
      removeEmptyAttributes: true,
      removeStyleLinkTypeAttributes: true
    }
  }));
  return customizedWebpackConfig;
}