'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports['default'] = checkPassword;

var _reactIntl = require('react-intl');

function checkPassword(passwordPolicy, value, callback, userName) {
  if (passwordPolicy) {
    var check = passwordPolicy.enablePassword,
        minLength = passwordPolicy.minLength,
        maxLength = passwordPolicy.maxLength,
        upcount = passwordPolicy.uppercaseCount,
        spcount = passwordPolicy.specialCharCount,
        lowcount = passwordPolicy.lowercaseCount,
        notEqualsUsername = passwordPolicy.notUsername,
        regexCheck = passwordPolicy.regularExpression;

    if (value && check) {
      var len = 0;
      var rs = '';
      var sp = void 0;
      var up = 0;
      var low = 0;
      for (var i = 0; i < value.length; i += 1) {
        var a = value.charAt(i);
        if (a.match(/[^\x00-\xff]/ig) != null) {
          len += 2;
        } else {
          len += 1;
        }
      }
      var pattern = new RegExp('[`~!@#$^&*()=%|{}\':;\',\\[\\].<>/?~！@#￥……&*（）——|{}【】‘；：”“\'。，、？]');
      for (var _i = 0; _i < value.length; _i += 1) {
        rs += value.substr(_i, 1).replace(pattern, '');
        sp = value.length - rs.length;
      }
      if (/[A-Z]/i.test(value)) {
        var ups = value.match(/[A-Z]/g);
        up = ups ? ups.length : 0;
      }
      if (/[a-z]/i.test(value)) {
        var lows = value.match(/[a-z]/g);
        low = lows ? lows.length : 0;
      }
      if (minLength && len < minLength) {
        callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.minLength' }) + { minLength: minLength });
        return;
      }
      if (maxLength && len > maxLength) {
        callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.maxLength' }) + { maxLength: maxLength });
        return;
      }
      if (upcount && up < upcount) {
        callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.upcount' }) + { upcount: upcount });
        return;
      }
      if (lowcount && low < lowcount) {
        callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.lowcount' }) + { lowcount: lowcount });
        return;
      }
      if (notEqualsUsername && value === userName) {
        callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.msg' }));
        return;
      }
      if (regexCheck) {
        var regex = new RegExp(regexCheck);
        if (regex.test(value)) {
          callback();
        } else {
          callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.regex' }));
        }
      }
      if (spcount && sp < spcount) {
        callback(React.createElement(_reactIntl.FormattedMessage, { id: 'password.characters' }) + { spcount: spcount });
      } else {
        callback();
      }
    } else {
      callback();
    }
  } else {
    callback();
  }
}