'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.warning = exports.dashboard = exports.authorize = exports.historyReplaceMenu = exports.historyPushMenu = exports.randomString = exports.handleResponseError = exports.checkPassword = exports.prompt = exports.logout = exports.getMessage = exports.intl = exports.languageChange = exports.removeAccessToken = exports.getAccessToken = exports.setAccessToken = exports.removeCookie = exports.getCookie = exports.setCookie = exports.AUTH_URL = exports.ACCESS_TOKEN = undefined;

var _style2 = require('yqcloud-ui/lib/message/style');

var _message = require('yqcloud-ui/lib/message');

var _message2 = _interopRequireDefault(_message);

var _url = require('url');

var _url2 = _interopRequireDefault(_url);

var _authorize = require('./authorize');

var _accessToken = require('./accessToken');

var _cookie = require('./cookie');

var _constants = require('./constants');

var _intl = require('./intl');

var _checkPassword = require('./checkPassword');

var _checkPassword2 = _interopRequireDefault(_checkPassword);

var _warning = require('../../common/warning');

var _warning2 = _interopRequireDefault(_warning);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

// 提示错误信息
function prompt(content) {
  var type = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'info';
  var duration = arguments[2];
  var placement = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'leftBottom';
  var onClose = arguments[4];

  var messageType = ['success', 'error', 'info', 'warning', 'warn', 'loading'];
  if (messageType.indexOf(type) !== -1) {
    _message2['default'][type](content, duration, onClose, placement);
  }
}

// 处理错误相应
function handleResponseError(error) {
  var response = error.response;

  if (response) {
    var status = response.status;

    switch (status) {
      case 400:
        {
          var mess = response.data.message;
          _message2['default'].error(mess);
          break;
        }
      default:
        break;
    }
  }
}

// 生成指定长度的随机字符串
function randomString() {
  var len = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 32;

  var code = '';
  var chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
  var maxPos = chars.length;
  for (var i = 0; i < len; i += 1) {
    code += chars.charAt(Math.floor(Math.random() * (maxPos + 1)));
  }
  return code;
}

/**
 * 清空子项目做的
 *   itsm项目列表记住的值清空
 */
var clearUserCache = function clearUserCache() {
  // 清空项目类型
  sessionStorage.removeItem('user_project');
  //  清空单据类型
  sessionStorage.removeItem('user_ticket');
};

function historyPushMenu(history, path, domain) {
  var method = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'push';

  // 切租户清除用户个性化缓存 如：itsm配置记住的项目
  clearUserCache();
  if (!domain || _constants.LOCAL) {
    history[method](path);
  } else if (!path) {
    window.location = '' + domain;
  } else {
    var reg = new RegExp(domain, 'g');
    if (reg.test(window.location.host)) {
      history[method](path);
    } else {
      window.location = domain + '/#' + path;
    }
  }
}

function historyReplaceMenu(history, path, uri) {
  historyPushMenu(history, path, uri, 'replace');
}

exports.ACCESS_TOKEN = _constants.ACCESS_TOKEN;
exports.AUTH_URL = _constants.AUTH_URL;
exports.setCookie = _cookie.setCookie;
exports.getCookie = _cookie.getCookie;
exports.removeCookie = _cookie.removeCookie;
exports.setAccessToken = _accessToken.setAccessToken;
exports.getAccessToken = _accessToken.getAccessToken;
exports.removeAccessToken = _accessToken.removeAccessToken;
exports.languageChange = _intl.intl;
exports.intl = _intl.intl;
exports.getMessage = _intl.getMessage;
exports.logout = _authorize.logout;
exports.prompt = prompt;
exports.checkPassword = _checkPassword2['default'];
exports.handleResponseError = handleResponseError;
exports.randomString = randomString;
exports.historyPushMenu = historyPushMenu;
exports.historyReplaceMenu = historyReplaceMenu;
exports.authorize = _authorize.authorize;
exports.dashboard = _constants.USE_DASHBOARD;
exports.warning = _warning2['default'];